# -*- coding: utf-8 -*-

# Symbols used
from sympy.abc import x, alpha, lamda
# Functions symbols used
from sympy import cos, exp, pi, sin
# Special symbols used
from sympy import oo
# Used to build random variables
from sympy.stats import ContinuousRV

def PDFe():
    # from sympy import diff
    # return(diff(CDFe(), x))
    return(-pi*alpha*(lamda*x)**alpha*exp(-(lamda*x)**alpha)*sin(pi*exp(-(lamda*x)**alpha)/2)/(2*x))

def CDFe():
    return(1-cos(                   \
            pi/2 *                  \
            exp(-(lamda*x)**alpha)))   

def buildRV(xName, alphaName, lamdaName):
    adjustedDensity = PDFe()
    adjustedDensity.subs(     \
        [(x, xName),          \
         (alpha, alphaName),          \
         (lamda, lamdaName)])
    return(ContinuousRV(xName, adjustedDensity, set=(0,oo)))


# -*- coding: utf-8 -*-

# Symbols used
from sympy.abc import x, alpha, theta
# Functions symbols used
from sympy import cos, exp, pi, sin
# Special symbols used
from sympy import oo
# Used to build random variables
from sympy.stats import ContinuousRV

def PDFe():
    # from sympy import diff
    # return(diff(CDFe(), x))
    return(pi*alpha*theta*x**(-theta)*exp(-alpha*x**(-theta))*cos(pi*exp(-alpha*x**(-theta))/2)/(2*x))

def CDFe():
    return(sin(                     \
       pi/2 *                      \
       (exp(-alpha*(x**-theta)))))

def buildRV(xName, alphaName, thetaName):
    adjustedDensity = PDFe()
    adjustedDensity.subs(     \
        [(x, xName),          \
         (alpha, alphaName),  \
         (theta, thetaName)])
    return(ContinuousRV(xName, adjustedDensity, set=(0,oo)))


# -*- coding: utf-8 -*-

# Symbols used
from sympy.abc import a, b, c, x, l
# Functions symbols used
from sympy import cos, exp, pi, sec, sin
# Special symbols used
from sympy import oo
# Functions used
from sympy import Rational
# Used to build random variables
from sympy.stats import ContinuousRV

def PDFe():
    # from sympy import diff
    # return(diff(CDFe(), x))
    return(pi*a*b*c*(l*x)**c*(1 - exp(-(l*x)**c))**a*(-(1 - exp(-(l*x)**c))**a + 1)**b*exp(-(l*x)**c)*sin(pi*(-(-(1 - exp(-(l*x)**c))**a + 1)**b/3 + Rational(1,3)))/(3*x*(1 - exp(-(l*x)**c))*(-(1 - exp(-(l*x)**c))**a + 1)*cos(pi*(-(-(1 - exp(-(l*x)**c))**a + 1)**b/3 + Rational(1,3)))**2))

def CDFe():
    # We aim to translate from \LaTeX into a expression and a function:
    # \sec(\frac{\pi}{3}(1-(1-(1-\exp(-(\lambda x)^c))^a)^b))-1
    return(sec(                  \
            pi/3 *               \
            (1-(1-(1-exp(-(l*x)**c))**a)**b))-1)    

def buildRV(xName, aName, bName, cName, lName):
    adjustedDensity = PDFe()
    adjustedDensity.subs(     \
        [(x, xName),          \
         (a, aName),          \
         (b, bName),          \
         (c, cName),          \
         (l, lName)])
    return(ContinuousRV(xName, adjustedDensity, set=(0,oo)))


# -*- coding: utf-8 -*-

from setuptools import setup

def readme():
    with open('README.rst') as f:
        return f.read()

setup(                                    \
    name = "trigdistrs",                  \
    version = "0.0a1",                    \
    description = 
        "Trigonometric Probability Distributions "
        "(see Souza 2016: NEW TRIGONOMETRIC CLASSES"
        " OF PROBABILISTIC DISTRIBUTIONS, PhD Thesis"
        "available at http://goo.gl/Z6nbJz)."
        "\n"
        "Uses symbolic computing with sympy.stats.",
    long_description = 
        "Probability distributions are elements of "
        "measure theory and general statistics,"
        "providing standardized formulas to compute"
        "odds of events happening."
        "\n"
        "This package presents new probability "
        "distributions produced by skewing regular"
        "distribution using trigonometric functions."        
        "\n"        
        "References:\n"
        "* http://goo.gl/Z6nbJz\n"
        "* CosW: https://cran.r-project.org/web/packages/CosW/index.html\n"
        "* SecKW: https://cran.r-project.org/web/packages/SecKW/index.html\n"
        "* SinIW: https://cran.r-project.org/web/packages/SinIW/index.html\n"
        "* TanB: https://cran.r-project.org/web/packages/TanB/index.html\n",
    classifiers = [
        "Development Status :: 1 - Planning",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "License :: DFSG approved",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Mathematics",
        "Topic :: Scientific/Engineering :: Physics",
        "Topic :: Education :: Computer Aided Instruction (CAI)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: Science/Research"
      ],
    keywords="Statistics Probability Distribution",
    url = "https://github.com/TrigonometricDistribution",
    author = "Lucas M. Soares Gallindo",
    author_email = "lucas.soares@ufpe.br",
    license = "GPLv3+",
    packages = ["trigdistrs"],
    install_requires = [
        "sympy",
    ],
    test_suite = "nose.collector",
    tests_require = ["nose"],
    include_package_data = True,
    zip_safe = False)


# -*- coding: utf-8 -*-

# print("Some remarks:")
# print(" * lambda is a reserved work in Python (used in anonymous functions);")
# print(" * O, N, Q, gamma, beta, I, S, C, pi, zeta, E are either reserved by Python or SymPy.")

from .CosW import buildRV as CosW
from .CosW import buildRV as CosineWeibull
from .SecKW import buildRV as SecKW
from .SecKW import buildRV as SecKumaraswamyWeibull
from .SinIW import buildRV as SinIW
from .SinIW import buildRV as SineInverseWeibull
from .TanB import buildRV as TanB
from .TanB import buildRV as TangentBurrXII


# -*- coding: utf-8 -*-

# Symbols used
from sympy.abc import c, k, s, x
# Functions symbols used
from sympy import cos, pi, tan
# Special symbols used
from sympy import oo
# Used to build random variables
from sympy.stats import ContinuousRV

def PDFe():
    # from sympy import diff
    # return(diff(CDFe(), x))
    return(-pi*c*k*(-(x/s)**c)**(-k)/(4*x*cos(pi*(-(x/s)**c)**(-k)/4)**2))

def CDFe():
    return(tan(                  \
            pi/4 *               \
            (1-(1+(x/s)**c))**-k))

def buildRV(xName, cName, kName, sName):
    adjustedDensity = PDFe()
    adjustedDensity.subs(     \
        [(x, xName),          \
         (c, cName),          \
         (k, kName),          \
         (s, sName)])
    return(ContinuousRV(xName, adjustedDensity, set=(0,oo)))